All Classes and Interfaces
Class
Description
An AWS Arn.
Link between an endpoint property and the
AwsEndpointAttribute it represents.GetRawMessageContentRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
WorkMail could not access the updated email content.
The requested email is not eligible for update.
The requested email could not be updated due to an error in the MIME content.
PutRawMessageContentRequest Marshaller
Provides the MIME content of the updated email message as an S3 object.
The requested email message is not found.
Represents a URL to be used internally for endpoint resolution.
Amazon S3 object representing the updated message content, in MIME format.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
Service client for accessing Amazon WorkMail Message Flow asynchronously.
A builder for creating an instance of
WorkMailMessageFlowAsyncClient.The parameters object used to resolve the auth schemes for the WorkMailMessageFlow service.
A builder for a
WorkMailMessageFlowAuthSchemeParams.An auth scheme provider for WorkMailMessageFlow service.
This includes configuration specific to Amazon WorkMail Message Flow that is supported by both
WorkMailMessageFlowClientBuilder and WorkMailMessageFlowAsyncClientBuilder.Service client for accessing Amazon WorkMail Message Flow.
A builder for creating an instance of
WorkMailMessageFlowClient.The parameters object used to resolve an endpoint for the WorkMailMessageFlow service.
An endpoint provider for WorkMailMessageFlow.
Class to expose the service client settings to the user.
A builder for creating a
WorkMailMessageFlowServiceClientConfiguration